; ##############################################################################
; ##############################################################################
; ##############################################################################
; INITIALISIERUNG																
;																				
ONE_WIRE_INITIALISIERUNG:
	; PORT + PIN definieren				
	cbi (OW_DDR), (OW_PIN_NR)	; AUF EINGANG	
	cbi (OW_PORT),(OW_PIN_NR)	; PULL-UP aus	
	; 1-wire-STATUS	sperren !			
	rcall STATUS_SPERREN_SETZEN	;  STATUS: gesperrt		
	;  1-WIRE-ROM-ID					
	ldi temp1,ROM_ID_BYTE1
	ldi temp2,ROM_ID_BYTE2
	ldi temp3,ROM_ID_BYTE3
	ldi temp4,ROM_ID_BYTE4
	ldi temp5,ROM_ID_BYTE5
	ldi temp6,ROM_ID_BYTE6
	ldi temp7,ROM_ID_BYTE7
	ldi temp8,ROM_ID_BYTE8
	STS(adr_OW_ROM_ID_BEREICH8+0),temp1
	STS(adr_OW_ROM_ID_BEREICH8+1),temp2
	STS(adr_OW_ROM_ID_BEREICH8+2),temp3
	STS(adr_OW_ROM_ID_BEREICH8+3),temp4
	STS(adr_OW_ROM_ID_BEREICH8+4),temp5
	STS(adr_OW_ROM_ID_BEREICH8+5),temp6
	STS(adr_OW_ROM_ID_BEREICH8+6),temp7
	STS(adr_OW_ROM_ID_BEREICH8+7),temp8
	; 1-WIRE CRC Check				
	rcall ONE_WIRE_ROM_CRC7
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
EXTERNER_INTERUPT_INITIALISIEREN:
;																			
; SLEEP+INT0+INT1 (externer Interrupt) konfigurieren						
;																			
; MCUCR => SE SM2 SM1 SM0 ISC11 ISC10 ISC01 ISC00 							
; SM2 SM1 SM0 Sleep Mode													
; 0   0   0   Idle															
; 0   0   1   ADC Noise Reduction											
; 0   1   0   Power-down													
; 0   1   1   Power-save													
; 1   0   0   Reserved														
; 1   0   1   Reserved														
; 1   1   0   Standby(1)													
;																			
;ISC11 ISC10 Description													
; 0 	0 	The low level of INT1 generates an interrupt request.			
; 0 	1 	Any logical change on INT1 generates an interrupt request.		
; 1 	0 	The falling edge of INT1 generates an interrupt request.		
; 1 	1 	The rising edge of INT1 generates an interrupt request.			
;																			
;ISC01 ISC00 Description													
; 0 	0 	The low level of INT0 generates an interrupt request.			
; 0 	1 	Any logical change on INT0 generates an interrupt request.		
;*1 	0 	The falling edge of INT0 generates an interrupt request.		
; 1 	1 	The rising  edge of INT0 generates an interrupt request.		
;																			
	ldi temp,(0<<SE)|(0<<SM2)|(0<<SM1)|(0<<SM0)|(0<<ISC11)|(0<<ISC10)|(1<<ISC01)|(0<<ISC00) 
	out MCUCR,temp
ret
; ##############################################################################
EXTERNER_INTERRUPT_AKTIVIEREN:
;																			
; INT0+INT1 (externer Interrupt)aktivieren									
;																			
; GICR => INT1 INT0 - - - - IVSEL IVCE 										
; General Interrupt Control													
;																			
	ldi temp, (0<<INT1)|(1<<INT0)|(0<<IVSEL)|(0<<IVCE)   
    out GICR, temp 
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; sehr zeitkritisch ist das Schreiben eines 0-SLOT !							
;																				
; INP/OUT: SRAM(OW_STATUS)														
ONE_WIRE_INTERRUPT:
	; REGISTER sichern			
	push temp
	in temp,SREG							; SREG 
	push temp
	push temp1
	push ZL	
	push ZH	
	push YL
	push YH
;-------------------------------------------------------------------------------
; STATUS laden und abfragen														
	LDS temp,(adr_OW_STATUS)
	; 0-SLOT senden?			
	cpi temp,OW_STATUS_TX_0SLOT
	breq INTERRUPT_MODUS_WRITE_0SLOT
	; 1-SLOT senden?			
	cpi temp,OW_STATUS_TX_1SLOT
	breq INTERRUPT_MODUS_WRITE_1SLOT
	; gesperrt ?				
	cpi temp,OW_STATUS_GESPERRT
	breq INTERRUPT_RESET_PRESENCE_CHECK
	; Read-MODUS				
	rjmp INTERRUPT_MODUS_READ
;-------------------------------------------------------------------------------
; WRITE 0-SLOT																	
INTERRUPT_MODUS_WRITE_0SLOT:
	sbi (OW_DDR),(OW_PIN_NR)	; AUF AUSGANG	
	; PAUSE ca.25s (0-SLOT) MASTER SAMPLES nach ca 9s		
	rcall wait_5us
	rcall wait_5us
	rcall wait_5us
	rcall wait_5us
	rcall wait_5us
	cbi (OW_DDR), (OW_PIN_NR)		; AUF EINGANG	
	STS(adr_OW_STATUS),NULL			; STATUS-BEREIT	
rjmp INTERRUPT_AUSWERTUNG
; ------------------------------------------------------------------------------
; WRITE 1-SLOT																	
INTERRUPT_MODUS_WRITE_1SLOT:
	cbi (OW_DDR), (OW_PIN_NR)		; AUF EINGANG	
	STS(adr_OW_STATUS),NULL			; STATUS-BEREIT	
rjmp INTERRUPT_AUSWERTUNG
;-------------------------------------------------------------------------------
; READ 0/1 SLOT																	
INTERRUPT_MODUS_READ:
	; ca. 10s PAUSE				
	rcall wait_5us
	rcall wait_5us
	; SAMPLES !!! (PIN abfragen)	
	sbic (OW_PIN),(OW_PIN_NR)	; springe, wenn BIT(PIN) low	
	rjmp INTERRUPT_MODUS_READ_1SLOT
INTERRUPT_MODUS_READ_0SLOT:
	; READ 0 SLOT					
	ldi temp,(OW_STATUS_RX_0SLOT)
	STS(adr_OW_STATUS),temp					; STATUS						
	rjmp INTERRUPT_AUSWERTUNG
INTERRUPT_MODUS_READ_1SLOT:
	; READ 1 SLOT					
	ldi temp,(OW_STATUS_RX_1SLOT)
	STS(adr_OW_STATUS),temp					; STATUS						
	rjmp INTERRUPT_AUSWERTUNG
;-------------------------------------------------------------------------------
; AUSWERTUNG und Berechnung der ROM und Functions Commands						
INTERRUPT_AUSWERTUNG:
	rcall FUNCTION_COMMAND_AUSWERTUNG
	rcall ROM_COMMAND_AUSWERTUNG
;-------------------------------------------------------------------------------
; RESET and PRESENCE ?															
INTERRUPT_RESET_PRESENCE_CHECK:
	clr ZL
	clr ZH
INTERRUPT_RESET_PRESENCE_CHECK_SCHLEIFE:
	; PIN abfragen			
	sbic (OW_PIN),(OW_PIN_NR)	; springe, wenn BIT(PIN) low
	rjmp INTERRUPT_RESET_PRESENCE_CHECK_AUSWERTUNG
	; ZHLER				
	adiw ZL,1
	; BERLAUF ?			
	brcc INTERRUPT_RESET_PRESENCE_CHECK_SCHLEIFE
	; WDR ?					
	ldi temp,OW_BUS_RESET_ZULASSEN
	tst temp
	brne INTERRUPT_RESET_PRESENCE_CHECK_WDR
	; WDR !					
	WDR
INTERRUPT_RESET_PRESENCE_CHECK_WDR:
	; interrupts freigeben	
	sei
	cbi (LED_OW_ROT_PORT),LED_OW_ROT_PIN_NR						; ROT							
	; BERLAUF !			
	ldi ZL,255
	ldi ZH,255
	; 1-wire-STATUS	sperren !	
	rcall STATUS_SPERREN_SETZEN	;  STATUS: gesperrt	
	rjmp INTERRUPT_RESET_PRESENCE_CHECK_SCHLEIFE
	; AUSWERTUNG			
INTERRUPT_RESET_PRESENCE_CHECK_AUSWERTUNG:
	; vergleich (HIGH)		
	cpi ZH,255
	breq INTERRUPT_FERTIG
	; vergleich (HIGH)		
	tst ZH
	breq INTERRUPT_FERTIG
	; ZHLER				
	STS(adr_OW_ZAEHLER_RESET_PRESENCE_L),ZL	; speichern (Wartungszwecke)
	STS(adr_OW_ZAEHLER_RESET_PRESENCE_H),ZH
rjmp INTERRUPT_RESET_PRESENCE_IMPULS	
;-------------------------------------------------------------------------------
; RESET and PRESENCE !															
INTERRUPT_RESET_PRESENCE_IMPULS:
	; Pause				
	rcall wait_50us
	; Pause				
	sbi (OW_DDR), (OW_PIN_NR)	; AUF AUSGANG	
	rcall wait_50us
	rcall wait_50us
	rcall wait_50us
	cbi (OW_DDR), (OW_PIN_NR)	; AUF EINGANG	
	; CLEAR				
	STS(adr_OW_STATUS),NULL					; STATUS						
	STS(adr_OW_BIT_NUMMER_L),NULL		; BIT_NUMMER			
	STS(adr_OW_BIT_NUMMER_H),NULL	 	; BIT_NUMMER			
	STS(adr_OW_ZEIGER),NULL
	STS(adr_OW_RX_BYTE),NULL	
	STS(adr_OW_BIT_ZAEHLER),NULL
	STS(adr_OW_RX_ROM_COMMAND),NULL
	STS(adr_OW_RX_ROM_COMMAND_FERTIG),NULL
	STS(adr_OW_RX_FUNCTION_COMMAND),NULL
	STS(adr_OW_RX_FUNCTION_COMMAND_FERTIG),NULL
	; LEDs				
	sbi (LED_OW_GRUEN_PORT),LED_OW_GRUEN_PIN_NR				; GRN							
	sbi (LED_OW_GELB_PORT),LED_OW_GELB_PIN_NR				; GELB 							
	sbi (LED_OW_ROT_PORT),LED_OW_ROT_PIN_NR					; ROT							

rjmp INTERRUPT_FERTIG
;-------------------------------------------------------------------------------
INTERRUPT_FERTIG:
	; REGISTER wieder herstellen				
	pop YH
	pop YL
	pop ZH
	pop ZL
	pop temp1
	pop	temp
	OUT SREG, temp							; SREG	
	pop temp
	; eventuelle Pegelwechsel ignorieren
	out GIFR,VOLL							
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
; CRC Berechnung bernommen und abgendert von: http://s-huehn.de				
; CRC-Berechnung Application Note 27 von Dallas/Maxim							
;																				
; CRC-ROM																		
; INP: SRAM																		
;																				
ONE_WIRE_ROM_CRC7:
	push XL          ; auf dem Stack sichern            
	push XH
	push r16
	push r17
	push r18
	push r19
	push r20
	push r21
ONE_WIRE_ROM_CRC7_RUN:
	; INITIALISIERUNG
 	ldi XL,low (adr_OW_ROM_ID_BEREICH8+0) ;Zeiger 				
    ldi XH,high(adr_OW_ROM_ID_BEREICH8+0) 
    ldi     r19, 7                          ;7 Bytes berechnen			
    ldi     r20, 0x18                       ;Konstante fr Berechnung
    clr     r17                            ;CRC-Startwert = 0 setzen
ONE_WIRE_CRC7_100: 
	ld      r18, x+                         ;Byte aus Puffer holen
    mov     r21, r18                        ;Byte zwischenspeichern
    ldi     r16, 8                          ;8 Verschiebungen
ONE_WIRE_CRC7_200: 
	eor     r18, r17                      	;CRC berechnen
    ror     r18                             ;Ergebnis in Carry schieben
    mov     r18, r17                      	;letzten CRC-Wert holen
    brcc    ONE_WIRE_CRC7_300                          ;war Ergebnis = 0? ja -> weiter
    eor     r18, r20                        ;sonst CRC-Wert updaten
ONE_WIRE_CRC7_300: 
	ror     r18                             ;neuen CRC-Wert positionieren
    mov     r17, r18          	            ;und speichern
    mov     r18, r21                        ;restliche Bits holen
    bst     r18, 0                          ;LSB sichern, nchste Bitposition
    ror     r18                             ;gesichertes Bit als MSB einsetzen
    bld     r18, 7                          ;(Ersatz fr RR-Befehl)
    mov     r21, r18                        ;und Wert zwischenspeichern
    dec     r16                             ;alle Verschiebungen erledigt?
    brne    ONE_WIRE_CRC7_200               ;nein -> Schleife
    dec     r19                             ;alle Bytes bearbeitet?
    brne    ONE_WIRE_CRC7_100               ;nein -> Schleife
;-------------------------------------------------------------------------------
	LDS temp,(adr_OW_ROM_ID_BEREICH8+7)
	; Korrektur
	STS(adr_OW_ROM_ID_BEREICH8+7),R17
	cp temp,r17
	brne ONE_WIRE_CRC7_ERROR
	SEC										; CARRY=1	
	rjmp ONE_WIRE_CRC7_FERTIG
;-------------------------------------------------------------------------------
ONE_WIRE_CRC7_ERROR:
	; ERROR 
	cbi (LED_OW_ROT_PORT),(LED_OW_ROT_PIN_NR)	; ROT	
	rcall wait_100ms
	sbi (LED_OW_ROT_PORT),(LED_OW_ROT_PIN_NR)	; ROT	
	; nochmal prfen !			
	rjmp ONE_WIRE_ROM_CRC7_RUN
;-------------------------------------------------------------------------------
ONE_WIRE_CRC7_FERTIG:
	pop r21      							; wiederherstellen                	
	pop r20
	pop r19
	pop r18
	pop r17
	pop r16
	pop XH
	pop XL
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 	rcall STATUS_ABFRAGE_UMWANDLUNG_OUT_TEMP ; OUT: 0=0SLOT 1=1SLOT				
STATUS_ABFRAGE_UMWANDLUNG_OUT_TEMP_C:
	; STATUS laden und abfragen
	LDS temp,(adr_OW_STATUS)	
	cpi temp,(OW_STATUS_RX_1SLOT)
	breq STATUS_ABFRAGE_UMWANDLUNG_OUT_TEMP_1
STATUS_ABFRAGE_UMWANDLUNG_OUT_TEMP_0:
	ldi temp,0
	; Carry clear		
	CLC						
	ret
STATUS_ABFRAGE_UMWANDLUNG_OUT_TEMP_1:
	ldi temp,1
	; CARRY set			
	SEC							
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; einzelnes BIT im SRAM setzen (Version 07.07.2012)								
;																				
; INP:	CARRY (0=clear 1=setzen)												
;		SRAM (adr_OW_BIT_STARTADRESSE_L)										
;		SRAM (adr_OW_BIT_STARTADRESSE_H)										
;		SRAM (adr_OW_BIT_NUMMER_L)												
;		SRAM (adr_OW_BIT_NUMMER_H)												
;																				
; Hilfsregister: temp1/YL/YH/ZL/ZH 												
;																				
FUNKTION_SRAM_BIT_WRITE_C:
	; SICHERUNGSKOPIE	
	PUSH temp
	PUSH temp1
	PUSH YL
	PUSH YH
	PUSH ZH
	PUSH ZL
	; Carry=0 ?			
	BRCC FUNKTION_SRAM_BIT_WRITE_C0
	rjmp FUNKTION_SRAM_BIT_WRITE_C1
; ------------------------------------------------------------------------------
FUNKTION_SRAM_BIT_WRITE_C0:
	; HILFSREGISTER	temp1
	ldi temp1,0b00000000
	rjmp FUNKTION_SRAM_BIT_WRITE_C_RUN
FUNKTION_SRAM_BIT_WRITE_C1:
	; HILFSREGISTER	temp1
	ldi temp1,0b11111111
; ------------------------------------------------------------------------------
FUNKTION_SRAM_BIT_WRITE_C_RUN:
	; Y-BIT-NUMMER laden	
	LDS YL,(adr_OW_BIT_NUMMER_L)
	LDS YH,(adr_OW_BIT_NUMMER_H)
	; BITS(2..0) aufbereiten	
	mov temp,YL
	andi temp, 0b00000111
	; Y-BYTE aufbereiten		
	LSR YH			; 3xrechts	
	ROR YL
	LSR YH
	ROR YL
	LSR YH
	ROR YL
	; Z BIT-STARTADRESSE laden	
	LDS ZL,(adr_OW_BIT_STARTADRESSE_L)
	LDS ZH,(adr_OW_BIT_STARTADRESSE_H)
	; Z+'Y' addieren			
	add ZL,YL
	adc ZH,YH
	; vergleich	temp			
	cpi temp,0
	breq FUNKTION_SRAM_BIT_WRITE_C_B0
	cpi temp,1
	breq FUNKTION_SRAM_BIT_WRITE_C_B1
	cpi temp,2
	breq FUNKTION_SRAM_BIT_WRITE_C_B2
	cpi temp,3
	breq FUNKTION_SRAM_BIT_WRITE_C_B3
	cpi temp,4
	breq FUNKTION_SRAM_BIT_WRITE_C_B4
	cpi temp,5
	breq FUNKTION_SRAM_BIT_WRITE_C_B5
	cpi temp,6
	breq FUNKTION_SRAM_BIT_WRITE_C_B6
	rjmp FUNKTION_SRAM_BIT_WRITE_C_B7
FUNKTION_SRAM_BIT_WRITE_C_B0:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11111110	; BIT clear			
	andi temp1,0b00000001	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B1:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11111101	; BIT clear			
	andi temp1,0b00000010	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B2:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11111011	; BIT clear			
	andi temp1,0b00000100	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B3:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11110111	; BIT clear			
	andi temp1,0b00001000	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B4:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11101111	; BIT clear			
	andi temp1,0b00010000	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B5:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b11011111	; BIT clear			
	andi temp1,0b00100000	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B6:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b10111111	; BIT clear			
	andi temp1,0b01000000	; BITS aufbereiten	
	rjmp FUNKTION_SRAM_BIT_WRITE_C_FERTIG	
FUNKTION_SRAM_BIT_WRITE_C_B7:
	LD temp,Z				; Z-BYTE laden		
	andi temp ,0b01111111	; BIT clear			
	andi temp1,0b10000000	; BITS aufbereiten	
FUNKTION_SRAM_BIT_WRITE_C_FERTIG:
	; BITS verknpfen	
	or temp,temp1			
	; BYTE speichern	
	ST Z,temp				
	; BITNUMMER+1				
	LDS YL,(adr_OW_BIT_NUMMER_L)
	LDS YH,(adr_OW_BIT_NUMMER_H)
	adiw YL,1
	STS(adr_OW_BIT_NUMMER_L),YL
	STS(adr_OW_BIT_NUMMER_H),YH
	; WIEDERHERSTELLEN		
	POP ZH
	POP ZL
	POP YH
	POP YL
	POP temp1
	pop temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; einzelnes BIT im SRAM auslesen (Version 07.07.2012)							
;																				
;																				
; INP	SRAM (adr_OW_BIT_STARTADRESSE_L)										
;		SRAM (adr_OW_BIT_STARTADRESSE_H)										
;		SRAM (adr_OW_BIT_NUMMER_L)												
;		SRAM (adr_OW_BIT_NUMMER_H)												
; OUT:	CARRY+temp (0=clear 1=gesetzt)											
;																				
; Hilfsregister: temp1/YL/YH/ZL/ZH 												
;																				
; rcall rcall FUNKTION_SRAM_BIT_READ_TEMP_C	; inp: SRAM OUT: temp+Carry			
;																				
FUNKTION_SRAM_BIT_READ_TEMP_C:
	; SICHERUNGSKOPIE		
	PUSH temp1
	PUSH YL
	PUSH YH
	PUSH ZH
	PUSH ZL
	; Y-BIT-NUMMER laden	
	LDS YL,(adr_OW_BIT_NUMMER_L)
	LDS YH,(adr_OW_BIT_NUMMER_H)
	; BITS(2..0) aufbereiten	
	mov temp,YL
	andi temp, 0b00000111
	; Y-BYTE aufbereiten		
	LSR YH			; 3xrechts	
	ROR YL
	LSR YH
	ROR YL
	LSR YH
	ROR YL
	; Z BIT-STARTADRESSE laden	
	LDS ZL,(adr_OW_BIT_STARTADRESSE_L)
	LDS ZH,(adr_OW_BIT_STARTADRESSE_H)
	; Z+'Y' addieren			
	add ZL,YL
	adc ZH,YH
	; BYTE laden				
	LD temp1,Z
	; BITNUMMER+1				
	LDS YL,(adr_OW_BIT_NUMMER_L)
	LDS YH,(adr_OW_BIT_NUMMER_H)
	adiw YL,1
	STS(adr_OW_BIT_NUMMER_L),YL
	STS(adr_OW_BIT_NUMMER_H),YH
	; vergleich	temp			
	cpi temp,0
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B0
	cpi temp,1
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B1
	cpi temp,2
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B2
	cpi temp,3
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B3
	cpi temp,4
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B4
	cpi temp,5
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B5
	cpi temp,6
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B6
	cpi temp,7
	breq FUNKTION_SRAM_BIT_READ_TEMP_C_B7
; ------------------------------------------------------------------------------
FUNKTION_SRAM_BIT_READ_TEMP_C_B0:
	SBRS temp1,0						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B1:
	SBRS temp1,1						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B2:
	SBRS temp1,2						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B3:
	SBRS temp1,3						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B4:
	SBRS temp1,4						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B5:
	SBRS temp1,5						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B6:
	SBRS temp1,6						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
FUNKTION_SRAM_BIT_READ_TEMP_C_B7:
	SBRS temp1,7						; springe, wenn Bit set	
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_0
	rjmp FUNKTION_SRAM_BIT_READ_Z_TEMP_1
; ------------------------------------------------------------------------------
FUNKTION_SRAM_BIT_READ_Z_TEMP_0:
	; WIEDERHERSTELLEN		
	POP ZH
	POP ZL
	POP YH
	POP YL
	POP temp1

	clr temp						; OUT				
	CLC								; Carry clear		
	ret
FUNKTION_SRAM_BIT_READ_Z_TEMP_1:
	; WIEDERHERSTELLEN		
	POP ZH
	POP ZL
	POP YH
	POP YL
	POP temp1

	ldi temp,1						; OUT				
	SEC								; CARRY set			
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 	rjmp STATUS_SPERREN_SETZEN	;  STATUS: gesperrt								
STATUS_SPERREN_SETZEN:
	; SPERREN						
	ldi temp,(OW_STATUS_GESPERRT)
	STS(adr_OW_STATUS),temp	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
;	rcall STATUS_TX_0SLOT_SETZEN ; STATUS: TX-0SLOT								
STATUS_TX_0SLOT_SETZEN:
	; STATUS		
	ldi temp,(OW_STATUS_TX_0SLOT)
	STS(adr_OW_STATUS),temp	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
;	rcall STATUS_TX_1SLOT_SETZEN ; STATUS: TX-1SLOT								
STATUS_TX_1SLOT_SETZEN:
	; STATUS		
	ldi temp,(OW_STATUS_TX_1SLOT)
	STS(adr_OW_STATUS),temp	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################

